        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 23 <br>2,5,6,11,14,18,21,22,24,25,26,28,29,30,32,35,36,38,45,46,47,48,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 15 <br>3,4,7,8,9,10,16,19,27,33,37,39,40,42,43';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 13 <strong>control</strong><br>0,1,12,13,15,17,20,23,31,34,41,44,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 23 <br>2,5,6,11,14,18,21,22,24,25,26,28,29,30,32,35,36,38,45,46,47,48,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 15 <br>3,4,7,8,9,10,16,19,27,33,37,39,40,42,43';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 13 <strong>control</strong><br>0,1,12,13,15,17,20,23,31,34,41,44,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 23 <br>2,5,6,11,14,18,21,22,24,25,26,28,29,30,32,35,36,38,45,46,47,48,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 15 <br>3,4,7,8,9,10,16,19,27,33,37,39,40,42,43';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 13 <strong>control</strong><br>0,1,12,13,15,17,20,23,31,34,41,44,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 23 <br>2,5,6,11,14,18,21,22,24,25,26,28,29,30,32,35,36,38,45,46,47,48,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 15 <br>3,4,7,8,9,10,16,19,27,33,37,39,40,42,43';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 13 <strong>control</strong><br>0,1,12,13,15,17,20,23,31,34,41,44,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 23 <br>2,5,6,11,14,18,21,22,24,25,26,28,29,30,32,35,36,38,45,46,47,48,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>33</strong> miembros: 15 <br>3,4,7,8,9,10,16,19,27,33,37,39,40,42,43';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260511 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 13 <strong>control</strong><br>0,1,12,13,15,17,20,23,31,34,41,44,50';}
}
